package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````(`/@`!````L"5```````!``````````&"S````
M`````````$``.``-`$``'``;``8````$````0`````````!``$```````$``
M0```````V`(```````#8`@````````@``````````P````0````8`P``````
M`!@#0```````&`-````````<`````````!P``````````0`````````!````
M!`````````````````!``````````$```````.@3````````Z!,`````````
M$`````````$````%`````"``````````($`````````@0```````)3P`````
M```E/``````````0`````````0````0`````8`````````!@0````````&!`
M``````!02````````%!(`````````!`````````!````!@```."M````````
MX+U```````#@O4````````@$````````>`0`````````$`````````(````&
M````\*T```````#PO4```````/"]0```````X`$```````#@`0````````@`
M````````!`````0````X`P```````#@#0```````.`-```````!`````````
M`$``````````"``````````$````!````'@#````````>`-```````!X`T``
M`````$0`````````1``````````$`````````%/E=&0$````.`,````````X
M`T```````#@#0```````0`````````!```````````@`````````4.5T9`0`
M``"`H0```````("A0```````@*%```````#T`````````/0`````````!```
M``````!1Y71D!@``````````````````````````````````````````````
M```````````0`````````%+E=&0$````X*T```````#@O4```````."]0```
M````(`(````````@`@````````$`````````+VQI8C8T+VQD+6QI;G5X+7@X
M-BTV-"YS;RXR```````$````,`````4```!'3E4``H``P`0````!````````
M``$``<`$````"0`````````"``'`!`````$`````````!````!0````#````
M1TY5`%MT['?@F,T9K!BVH:='U:>00M0'!````!`````!````1TY5```````#
M`````@``````````````"0```#D````!````!@```%(+@`#``4`*.0```#H`
M```[````/````#T`````````/@```#\`````````R=6R<3GRBQR'^9R!I]VC
M:\6YG$`+BA!7>_!*:P```````````````````````````````/(````2````
M`````````````````````$H````2`````````````````````````'H````2
M`````````````````````````"H"```2`````````````````````````/L!
M```2``````````````````````````$````@````````````````````````
M`&$!```2`````````````````````````'\"```2````````````````````
M`````,,!```2`````````````````````````&T"```2````````````````
M``````````@!```2`````````````````````````'$````2````````````
M`````````````!T````2`````````````````````````)<!```2````````
M`````````````````+T!```2`````````````````````````(4````2````
M`````````````````````-4!```2`````````````````````````*T!```2
M`````````````````````````-(````2`````````````````````````/<`
M```2`````````````````````````+8!```2````````````````````````
M``H"```2`````````````````````````#@"```2````````````````````
M`````$(!```2`````````````````````````+\````6````````````````
M`````````!X!```2`````````````````````````*(````2````````````
M`````````````(\!```2`````````````````````````(@!```2````````
M`````````````````,@!```2`````````````````````````),````2````
M`````````````````````-P!```2`````````````````````````)X!```2
M`````````````````````````#$"```2`````````````````````````+$`
M```2`````````````````````````%P"```2````````````````````````
M`'@!```2`````````````````````````"T````2````````````````````
M`````%`!```2`````````````````````````%4"```2````````````````
M`````````*8!```2``````````````````````````D"```2````````````
M`````````````$`"```2`````````````````````````-T````2````````
M`````````````````/P````2`````````````````````````&8!```2````
M`````````````````````'\!```2`````````````````````````.T!```2
M`````````````````````````$<"```2`````````````````````````.4!
M```2`````````````````````````%8````2````````````````````````
M``\!```2`````````````````````````!$"```2````````````````````
M`````$X"```2`````````````````````````&X!```2````````````````
M`````````,\!```2`````````````````````````"\!```2````@"!`````
M`````````````","```1`!D`(,)````````(`````````#D````2````P"%`
M`````````````````'<"```A`!D``,)````````(`````````'4"```1`!D`
M`,)````````(`````````!`````1`!D`,,)````````!`````````&$````2
M````L"%```````````````````!?7V=M;VY?<W1A<G1?7P!03%]D;U]U;F1U
M;7``4&5R;%]G=E]F971C:'!V`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7VQO
M8VL`4&5R;%]G971?<W8`4&5R;%]N97=84P!B;V]T7T1Y;F%,;V%D97(`<&5R
M;%]R=6X`<&5R;%]P87)S90!097)L7W-V7W-E='!V`%!E<FQ?<W9?<V5T<'9N
M`'!E<FQ?8V]N<W1R=6-T`'!E<FQ?9&5S=')U8W0`4$Q?8W5R<F5N=%]C;VYT
M97AT`'!E<FQ?86QL;V,`4&5R;%]C<F]A:U]N;V-O;G1E>'0`<&5R;%]F<F5E
M`%!E<FQ?<V%F97-Y<VUA;&QO8P!097)L7W-Y<U]I;FET,P!097)L7VYE=UA3
M7V9L86=S`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-Y<U]T97)M`%]?<W1A
M8VM?8VAK7V9A:6P`97AI=`!L<V5E:S8T`')E861D:7(V-`!S=')D=7``8VQO
M<V5D:7(`;W!E;C8T`'-T<G)C:'(`=6YL:6YK`&UE;6UO=F4`<W1R=&]K`&=E
M='!W=6ED`'-T<FQE;@!R;61I<@!R96%D`'-T<G-T<@!M:V1I<@!G971P:60`
M<F5A9&QI;FL`<F5A;&QO8P!?7W-P<FEN=&9?8VAK`%]?9G!R:6YT9E]C:&L`
M;'-T870V-`!?7VQI8F-?<W1A<G1?;6%I;@!S=&1E<G(`;65M8VAR`'-T<F-H
M<@!O<&5N9&ER`&=E='5I9`!A8V-E<W,`;65M8W!Y`'-T<F-M<`!?7V5R<FYO
M7VQO8V%T:6]N`'-T<FYC;7``7U]E;G9I<F]N`%]?<F5G:7-T97)?871F;W)K
M`&QI8G!E<FPN<V\N-2XS-@!L:6)C+G-O+C8`1TQ)0D-?,BXQ-`!'3$E"0U\R
M+C,T`$=,24)#7S(N-`!'3$E"0U\R+C,S`$=,24)#7S(N,RXR`$=,24)#7S(N
M,RXT`$=,24)#7S(N,BXU`````0`!``$``@`#``$``@`$``(``@`"``$``0`"
M``(``0`"``(``0`"``(`!0`"``$``0`!``$``@`"``(``0`"``(``@`!``(`
M`@`!``8``@`"``4``@`!``$``@`"``,``@`"``$``0`'``@``@`"``$``@`!
M``(``@`!``$``````````0`'`*$"```0`````````)21E@8```@`JP(``!``
M``"TD98&```'`+8"```0````%&EI#0``!@#!`@``$````+.1E@8```4`RP(`
M`!````!R&6D)```$`-8"```0````=!EI"0```P#B`@``$````'4::0D```(`
M[@(```````#0OT````````8````&``````````````#8OT```````!(````9
M``````````````#@OT````````8````U````````````````PD````````4`
M```]```````````````@PD````````4````Z```````````````PPD``````
M``4````^````````````````P$````````<````!```````````````(P$``
M``````<````"```````````````0P$````````<````#```````````````8
MP$````````<````$```````````````@P$````````<````%````````````
M```HP$````````<````Y```````````````PP$````````<````'````````
M```````XP$````````<````(``````````````!`P$````````<````)````
M``````````!(P$````````<````*``````````````!0P$````````<````+
M``````````````!8P$````````<````,``````````````!@P$````````<`
M```-``````````````!HP$````````<````.``````````````!PP$``````
M``<````/``````````````!XP$````````<````0``````````````"`P$``
M``````<````1``````````````"(P$````````<````2``````````````"0
MP$````````<````3``````````````"8P$````````<````4````````````
M``"@P$````````<````5``````````````"HP$````````<````6````````
M``````"PP$````````<````7``````````````"XP$````````<````8````
M``````````#`P$````````<````_``````````````#(P$````````<````[
M``````````````#0P$````````<````:``````````````#8P$````````<`
M```;``````````````#@P$````````<````<``````````````#HP$``````
M``<````=``````````````#PP$````````<````>``````````````#XP$``
M``````<````?````````````````P4````````<````@```````````````(
MP4````````<````A```````````````0P4````````<````B````````````
M```8P4````````<````C```````````````@P4````````<````D````````
M```````HP4````````<````E```````````````PP4````````<````F````
M```````````XP4````````<````G``````````````!`P4````````<````H
M``````````````!(P4````````<````I``````````````!0P4````````<`
M```J``````````````!8P4````````<````K``````````````!@P4``````
M``<````L``````````````!HP4````````<````M``````````````!PP4``
M``````<````N``````````````!XP4````````<````O``````````````"`
MP4````````<````P``````````````"(P4````````<````Q````````````
M``"0P4````````<````R``````````````"8P4````````<````S````````
M``````"@P4````````<````T``````````````"HP4````````<````V````
M``````````"PP4````````<````W``````````````"XP4````````<````X
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!(@^P(2(L%Q9\``$B%P'0"_]!(@\0(PP```````````/\URI\``/\ES)\`
M``\?0`#_)<J?``!H`````.G@_____R7"GP``:`$```#IT/____\ENI\``&@"
M````Z<#_____);*?``!H`P```.FP_____R6JGP``:`0```#IH/____\EHI\`
M`&@%````Z9#_____)9J?``!H!@```.F`_____R62GP``:`<```#I</____\E
MBI\``&@(````Z6#_____)8*?``!H"0```.E0_____R5ZGP``:`H```#I0/__
M__\E<I\``&@+````Z3#_____)6J?``!H#````.D@_____R5BGP``:`T```#I
M$/____\E6I\``&@.````Z0#_____)5*?``!H#P```.GP_O___R5*GP``:!``
M``#IX/[___\E0I\``&@1````Z=#^____)3J?``!H$@```.G`_O___R4RGP``
M:!,```#IL/[___\E*I\``&@4````Z:#^____)2*?``!H%0```.F0_O___R4:
MGP``:!8```#I@/[___\E$I\``&@7````Z7#^____)0J?``!H&````.E@_O__
M_R4"GP``:!D```#I4/[___\E^IX``&@:````Z4#^____)?*>``!H&P```.DP
M_O___R7JG@``:!P```#I(/[___\EXIX``&@=````Z1#^____)=J>``!H'@``
M`.D`_O___R72G@``:!\```#I\/W___\ERIX``&@@````Z>#]____)<*>``!H
M(0```.G0_?___R6ZG@``:"(```#IP/W___\ELIX``&@C````Z;#]____):J>
M``!H)````.F@_?___R6BG@``:"4```#ID/W___\EFIX``&@F````Z8#]____
M)9*>``!H)P```.EP_?___R6*G@``:"@```#I8/W___\E@IX``&@I````Z5#]
M____)7J>``!H*@```.E`_?___R5RG@``:"L```#I,/W___\E:IX``&@L````
MZ2#]____)6*>``!H+0```.D0_?___R5:G@``:"X```#I`/W___\E4IX``&@O
M````Z?#\____)4J>``!H,````.G@_/___R5"G@``:#$```#IT/S___\E.IX`
M`&@R````Z<#\____)3*>``!H,P```.FP_/___R4JG@``:#0```#IH/S___\E
M(IX``&@U````Z9#\____)1J>``!H-@```.F`_/___R42G@``:#<```#I</S_
M_U-(@^PPB7PD'$B-?"0<2(ET)!!(C70D$$B)5"0(2(U4)`AD2(L$)2@```!(
MB40D*#'`Z(G___^Z@"!``+_`(4``2(G6Z!<X``"`/3">````#X0&`0``2(L%
MRYL``&1(BP"`B"H$```#BT0D'(UX!(U8`TAC_TC!YP/HTO[__TB+?"001(M$
M)!Q(B<%(B04&G@``2(L'2,=!",-A0`!(QT$8QF%``$B)`4B+!8&=``!(B4$0
M08/X`0^.'`$``$B#QPA!@\`#N@0```!F#Q]$``!(BP=(8_*#P@%(@\<(2(D$
M\40YPG7J2&/22(L]L)T``$4QP+Z`+4``2,<$T0````")VNB9^___B<.%P'1_
M2(L]C)T``.B7_?__,<!(C70D)+^C8$``Z,8!``!(A<!T<$B+/6J=``#H1?O_
M_^BP_/__2(M$)"AD2"L$)2@````/A9D```!(@\0PB=A;P^@__/__2(D%.)T`
M`$B)QTB%P'1SZ+O\__](BP6LF@``9$B+$,:"UPD```#IT?[__TB+/0V=``#H
MF/O__XG#Z6[___](BSWJG```2(7_=`KH(!L``.EZ____OUA@0`!(C70D).@L
M`0``2(D%Q9P``$B)QTB%P`^$6/___^O2N@0```#I`____[\!````Z//Z___H
M_OS__V8N#Q^$```````/'T``,>U)B=%>2(GB2(/D\%!413'`,<E(Q\>P(T``
M_Q4/F@``]&8N#Q^$```````/'T``PV8N#Q^$```````/'T0``+CHP4``2#WH
MP4``=!.X`````$B%P'0)O^C!0`#_X&:0PV9F+@\?A```````#Q]``+[HP4``
M2('NZ,%``$B)\$C![C](P?@#2`'&2-'^=!&X`````$B%P'0'O^C!0`#_X,-F
M9BX/'X0```````\?0`#S#Q[Z@#W&FP```'4354B)Y>AZ____Q@6TFP```5W#
MD,-F9BX/'X0```````\?0`#S#Q[ZZXIF+@\?A```````05=!5D%505154TB#
M[`A(A?\/A+$```!,BS5"FP``387V#X2A````#[8'28G_28GUA,!T!#P]=5A%
M,>1)BQY(A=MT,TUCY$R)]0\?@`````!,B>),B?Y(B=_HPOG__X7`=0="@#PC
M/71'2(M="$B#Q0A(A=MUVDB#Q`A(B=A;74%<05U!7D%?PP\?A```````28G\
M00^V1"0!28/$`83`=`0\/77N12G\ZY%F#Q]$``!,*?5*C5PC`4C!_0-!B6T`
MZ[1F#Q]$```QV^NJ#Q]``%-(B?M(@>R@````9$B+!"4H````2(F$))@````Q
MP$B)YN@Z^___A<!U-HM4)!B!X@#P``"!^@!```!T"('Z`*```'4>O@(```!(
MB=_H?_O__X7`#Y3`#[;`ZP</'T0``#'`2(N4))@```!D2"L4)2@```!U"4B!
MQ*````!;P^BM^O__9F8N#Q^$``````!FD$%505154TB![*@```!D2(L$)2@`
M``!(B80DF````#'`2(7_=`B`/P!(B?MU*TB+A"28````9$@K!"4H````#X4;
M`0``2('$J````%M=05Q!7<-F#Q]$``#H,_G__TF)Q$B%P'3(3(GGZ"/[__](
MA<`/A*H```"`>!,N2(UH$W40@'T!`'3?9BX/'X0``````(!X$RX/A)X```!(
MB=_HSOC__TB)[TF)Q>C#^/__08U\!0)(8__H%OC__TF)Z4F)V+D$8$``28G%
M2(G'O@$````QP$C'PO_____H4OK__TR)[TB)YNB7^/__3(GO@_C_=!"+1"08
M)0#P```]`$```'17Z/KW__],B>_H4OC__TR)Y^AZ^O__2(7`#X57____D$R)
MY^CX^?__2(G?Z.#W___I^/[__P\?`(!]`2X/A5C___^`?0(`#X09____Z4G_
M__\/'X``````Z*/^___KI^@\^?__9F8N#Q^$``````"0052Z`@```#'V08G\
M55-(@>P0``$`9$B+!"4H````2(F$)`@``0`QP$B)X^AP^?__2(UH_TB)ZDC!
M^C](P>HP2(U$%0`/M\!(*=!(*<4/B)$````/'T0``#'22(GN1(GGZ#OY__^Z
M"``!`$B)WD2)Y^C+]O__2)A(@_@'=E-(C40#^$@YV',2ZT</'X``````2(/H
M`4@YV'(W2(L-P)<``$@Y"'7K2"G82`'H2(N4)`@``0!D2"L4)2@```!U+TB!
MQ!```0!;74%<PV8/'T0``$B![0```0!(@?T``/__#X5T____2,?`_____^N^
MZ#[X__]F9BX/'X0```````\?`$%4NO\/``!52(GU4TB)^[\*8$``2('L$!``
M`&1(BP0E*````$B)A"0($```,<!(B>;HBO?__X7`?A*)P8/H`4ACT(`\%`!U
M2(7`=3Q(BP45E0``2(GJ2(G>9$B+..A.]O__2(N$)`@0``!D2"L$)2@```!U
M3DB!Q!`0``!;74%<PP\?@`````")P68/'T0``$QCX;XO````2(GG3(GBZ$WU
M__](A<!TI$B+!;F4``!,B>%(B>)(B=YD2(LXZ._V___KG^AH]___#Q^$````
M``!!5T%6055!5%5(B?532(G[2(/L&&1(BP0E*````$B)1"0(,<`QP(`^/0^4
MP$@!Q4B)[^CY]?__2(UT)`1(B=])B<0QP.@7^___2(7`#X0&`0``2(G'28G%
MZ-/U__],.>`/@](```!,8W0D!$G!Y@,/M@.$P`^$G@$``#P]#X26`0``2(G8
M#Q\`#[90`4B#P`&$TG0%@/H]=>](*=A(F$R++1N6``!*C7P@`NCA]/__30'U
M28E%`$B%P'162(L%_I4``$B-2P%*BQ0P#[8#B`*$P'0B/#UU#>L<#Q^`````
M`(3`=!$/M@%(@\(!2(/!`8@"/#UUZ\8"/3'`9@\?1```#[9,!0"(3`(!2(/`
M`83)=>](BT0D"&1(*P0E*`````^%!P$``$B#Q!A;74%<05U!7D%?PP\?0``Q
MP&8/'T0```^V5`4`08A4!0!(@\`!A-)U[NN]#Q]``$R+/6&5``!)@S\`#X2V
M````3(GX13'MD$B#P`A$B>I!@\4!2(,X`'7OC7(#2&/V2,'F`XL%9Y4``(7`
M=5O'!5F5```!````2(GWZ.GS__](A<`/A&'___]-8_5,B?Y(B<=)P>8#3(GR
MZ#OU__](B07TE```2(G!08U%`42);"0$2)A(QP3!`````.F(_O__9@\?A```
M````3(G_Z!CV__](B07!E```2(G!2(7`#X0&____36/U2<'F`^N[#Q]``#'`
MZ7_^__^^$````$4Q[>E?____Z"_U__]F9BX/'X0```````\?0`!3N0BA0`"Z
ML"%``+X98$``2(L=09(``&1(BSOHP/7__V1(BSM%,<E;0;B@84``NH`^0`"^
M-6!``$R)P>D0]/__N0BA0`"ZL"%``+X98$``2(L%`I(``&1(BSCI@?7__Y!3
M2('L("```&1(BP0E*````$B)A"08(```,<#H,//__[H!$```O@$```!(B>=!
MB<!!N15@0``QP+E*8$``Z`[U__^Z`!```$B-M"00$```2(GGZ/GS__^%P'A4
MC7@!2(G#2&/_Z(?R__](A<!T04ACVTB-M"00$```2(G'2(G:Z!SU___&!!@`
M2(G!2(N$)!@@``!D2"L$)2@```!U#$B!Q"`@``!(B<A;P^@1]/__,<GKV&9F
M+@\?A```````9I#I.____V9F+@\?A```````055!5$F)_+]88$``55-(B?-(
M@>RX$```9$B+!"4H````2(F$)*@0```QP$B-="0,Z+OW__^^+P```$R)YTB)
MQ>A;\___2(7`=#XQP$R)YK]A8$``Z#?\__],B>!(BY0DJ!```&1(*Q0E*```
M``^%AP$``$B!Q+@0``!;74%<05W##Q^``````$B)W^A`\___OFY@0`!(B<?H
M<_/__TB)PTB%P'2E@#L`#X3=````9I!(A>UT$TB)WDB)[^A`\___A<`/A*(`
M``!(B=_H\/'__TB-5`/_28G%2#G3<@_K'9#&`@!(@^H!2#G3=`6`.B]T[TB)
MW^C'\?__28G%3(GGZ+SQ__])C40%`4@]_P\```^'-?___TB#[`BY6V%``+H`
M$```,<!!5$&Y<&!``$F)V+X!````2(V\)+````#H/O/__TB-="0@2(V\)+``
M``#H?/'__UI9A<!U$(M$)"@E`/```#T`@```=%:^;F!``#'_Z)KR__](B<-(
MA<`/A,C^__^`.P`/A27___](A>UT!H!]`"YT&D&]`0```+M68$``Z5;___]F
M+@\?A```````@'T!`'2TZ]X/'X0``````+X!````2(V\)*````#HOO+__X7`
M=91(C;0DH````+]A8$``Z*CZ__](C;PDH````.C;\?__Z6+^___H\?'__Y!3
MOB\```!(B?OH,O'__TB-4`%(A<!(#T7:2(G?6^FN\?__9F8N#Q^$```````/
M'P!54TB![!@0``!D2(L$)2@```!(B80D"!```#'`2(7_#X3+````@#\`2(G[
M#X2_````Z%KP__](C5`!2('Z`!````^'X0```$B)Y4B)[X/Z"'(.B=%(B=[!
MZ0/S2*5(B?,QR?;"!'0)BPN)#[D$````]L("=`Y$#[<$"V9$B00/2(/!`H/B
M`70'#[84"X@4#TB-1`7_2#G%<A/K%@\?1```Q@``2(/H`4@YZ'0%@#@O=.^^
M+P```$B)[^A2\/__2(7`="U(.<5R6$B)[^C0\/__2(N4)`@0``!D2"L4)2@`
M``!U24B!Q!@0``!;7<,/'P!(BX0D"!```&1(*P0E*````'4I2('$&!```+]6
M8$``6UWIBO#__V8N#Q^$``````#&``#KHP\?`#'`ZZ3HC_#__V9F+@\?A```
M````#Q]``$B#[!AD2(L$)2@```!(B40D"#'`#Q]``#'`2(UT)`2_<F!``.A7
M]/__2(7`=#I(8U0D!$B+!::/``!(C0302(M0"$B)$$B%TG3.9@\?1```2(M0
M$$B#P`A(B1!(A=)U\.NV9@\?1```,<!(C70D!+][8$``Z`?T__](A<!T.DAC
M5"0$2(L%5H\``$B-!-!(BU`(2(D02(72=,YF#Q]$``!(BU`02(/`"$B)$$B%
MTG7PZ[9F#Q]$```QP$B-="0$OX-@0`#HM_/__TB%P'0Z2&-4)`1(BP4&CP``
M2(T$T$B+4`A(B1!(A=)TSF8/'T0``$B+4!!(@\`(2(D02(72=?#KMF8/'T0`
M`#'`2(UT)`2_C&!``.AG\___2(7`=#I(8U0D!$B+!;:.``!(C0302(M0"$B)
M$$B%TG3.9@\?1```2(M0$$B#P`A(B1!(A=)U\.NV9@\?1```,<!(C70D!+^3
M8$``Z!?S__](A<!T.DAC5"0$2(L%9HX``$B-!-!(BU`(2(D02(72=,YF#Q]$
M``!(BU`02(/`"$B)$$B%TG7PZ[9F#Q]$```QP$B-="0$OZ-@0`#HQ_+__TB%
MP'0Z2&-4)`1(BP46C@``2(T$T$B+4`A(B1!(A=)TSF8/'T0``$B+4!!(@\`(
M2(D02(72=?#KMF8/'T0``#'`2(UT)`2_6&!``.AW\O__2(7`=#I(8U0D!$B+
M!<:-``!(C0302(M0"$B)$$B%TG3.9@\?1```2(M0$$B#P`A(B1!(A=)U\.NV
M9@\?1```,<!(C70D!+^O8$``Z"?R__](A<!T.DAC5"0$2(L%=HT``$B-!-!(
MBU`(2(D02(72=,YF#Q]$``!(BU`02(/`"$B)$$B%TG7PZ[9F#Q]$```QP$B-
M="0$O[E@0`#HU_'__TB%P'0Z2&-4)`1(BP4FC0``2(T$T$B+4`A(B1!(A=)T
MSF8/'T0``$B+4!!(@\`(2(D02(72=?#KMF8/'T0``#'`2(UT)`2_PV!``.B'
M\?__2(7`=#I(8U0D!$B+!=:,``!(C0302(M0"$B)$$B%TG3.9@\?1```2(M0
M$$B#P`A(B1!(A=)U\.NV9@\?1```,<!(C70D!+]A8$``Z#?Q__](A<!T.DAC
M5"0$2(L%AHP``$B-!-!(BU`(2(D02(72=,YF#Q]$``!(BU`02(/`"$B)$$B%
MTG7PZ[9F#Q]$``!(C70D!+_-8$``Z.GP__](A<!T#TB)QK^Y8$``,<#H=?7_
M_S'`2(UT)`2_WF!``.C$\/__2(7`=`](B<:_\&!``#'`Z%#U__](C70D!+_[
M8$``,<#HG_#__TB)QDB%P'0QOUA@0``QP.@K]?__2(M$)`AD2"L$)2@```!U
M/+X<84``OY-@0``QP$B#Q!CI!O7__S'`2(UT)`2_"V%``.A5\/__2(7`=,5(
MB<:_KV!``#'`Z.'T___KM.@Z[/__9BX/'X0``````$B#[!B_KV!``&1(BP0E
M*````$B)1"0(,<!(C70D!.@-\/__2(7`=#`/MA"`^C`/E,"$T@^4P@G0@_`!
M#[;`2(M4)`AD2"L4)2@```!U#DB#Q!C##Q]$```QP.OBZ,_K__]F9BX/'X0`
M``````\?0`!(@^P(Z/?K__^)Q^A0ZO__2(7`=`-(BP!(@\0(PP\?`$%454B)
M_;\>84``4TB#[!!D2(L$)2@```!(B40D"#'`2(UT)`3H=N___TB%P'0(@#@`
M2(G#=3%(BT0D"&1(*P0E*`````^%L````$B)[DB#Q!"_'F%``#'`6UU!7.G>
M\___9@\?1```2(GN2(G'Z)WJ__](A<!T($B+1"0(9$@K!"4H````=7-(@\00
M6UU!7,,/'X``````2(GOZ-#I__](B=])B<3HQ>G__TF-?`0"Z!OI__](@^P(
M28GHN5MA0`!32,?"_____TB)QTF)Q$&Y;F!``+X!````,<#H3^O__UA:2(M$
M)`AD2"L$)2@```!U"$R)YNE3____Z*#J__]!5T%6055!5%5(B?V_6&!``%-(
M@>QH`0``9$B+!"4H````2(F$)%@!``"X-6%``$B-="0,2,=$)"``````2,=$
M)'@`````2,=$)$``````9D@/;L"XZ6!```\6!;AH```/*40D$&9(#V[`N`9A
M0``/%@6J:```#Q%$)%AF2`]NP+A&84``#Q8%G&@```\11"1H9D@/;L`QP`\6
M!9%H```/*40D,.CW[?__2(7`=`R`.`!(B<,/A48$``#H(>K__XG'Z'KH__](
MA<`/A,$#``!(BQA(A=L/A+4#``!(B=_HC>C__TB-?``!Z./G__]$#[8#28G%
M28G$183`=#0/'T``10^VP$R)[[E484``,<!(Q\+_____O@$```!(@\,!28/%
M`N@)ZO__1`^V`T6$P'703(UL)%B_\&!``.L1#Q]``$F+?0!)@\4(2(7_=#M(
MC70D##'`Z$?M__](B<-(A<!TWX`X`'3:2(G'Z`+N__^%P'3.2(G?Z`;I__](
MB<-(A<!U/F8/'T0``$R-;"0028M=`$B%VW0J@#L`#X3A`@``2(G?Z,GM__^%
MP`^%\0```$F+70A)@\4(2(7;==H/'T``2(G?Z*CG__],B>=)B<7HG>?__T6-
MM`4$!```36/V3(GWZ.KF__]!5$F)V$&Y<&!``&AB84``2(G'28G%N5EA0`!(
MQ\+_____O@$````QP.@<Z?__3(GOOL`!``#H?^G__U]!6(/X_W42Z$+H__]$
MBPA!@_D1#X6A`@``2(VT)(````!,B>_HA>C__XG#A<!T;TB+30!(BSW$AP``
M38GH,<"Z$&)``+X!````Z`#F__]%,>1(BX0D6`$``&1(*P0E*`````^%[P,`
M`$B!Q&@!``!,B>!;74%<05U!7D%?PY!(B=])@\4(Z-3G__](B<-(A<`/A-7^
M___I`____P\?`(N$))@````E`/```#T`0```#X5Z____1(ND))P```#H_.?_
M_T$YQ`^%9/___XN$))@````E_P$``#W``0``#X5-____3(GWZ,3E__](C70D
M#+\I84``28G$,<#H@.O__TB%P`^$-P(``$B+?0!(B<;H>_/__TF)QTB%P`^$
M'P(``$R)_^@GYO__28G&@_@#?C=(F+YG84``28U\!_SH3N?__X7`=2)!@_X$
M#X30`@``08U&^TB808`\!R\/A+\"```/'X``````,<!(C70D#+^O8$``Z`?K
M__](A<`/A,X!```/M@"$P`^$PP$``#PP#X2[`0``OAQA0`"_KV!``#'`Z'KO
M___H9>7__VB@84``38GH3(GG4$C'PO____]!N7!@0``QP+F`84``O@$```#H
M.^?__UA:ZTP/'X``````Z&OF__^#.!%U3>@AY?__@\,!2(/L"$V)Z&B@84``
M0;EP8$``3(GGN8YA0`!32,?"_____[X!````4#'`Z._F__](@\0@OL`!``!,
MB>?H3N?__X/X_W2I3(GOZ`'E__],B>:_6&!``#'`Z-+N__],B>?HBOK__^GX
M_?__#Q]$```QV^DY_?__9@\?A```````3(UD)##K#68/'X0``````$F#Q`A)
MBSPD2(7_#X2'````,<!(C70D#.CCZ?__2(7`=-Z`.`!TV4B)Q^BQY?__2(G#
M2(7`=,GI__O__TB+30!(BSTYA0``38GH,<"ZT&%``+X!````Z'7C___I</W_
M_TB)Q^CX^?__2(N$)%@!``!D2"L$)2@````/A5H!``!(@<1H`0``2(G?6UU!
M7$%=05Y!7^E(Y?__OPT```"[+F%``.B)X___0;A3````28G%28G$Z:C[__\/
M'X0``````$R+?0#IV/W__P\?@``````Q]DR)_S'`Z(3D__^)Q87`#X0O_O__
MB<?HX^O__TF)QDB%P`^('/[__S'22(UP]HGOZ&KE__^Z!@```$B-M"0:`0``
MB>_H]N+__X&\)!H!````0T%##X7J_?__9H&\)!X!``!(10^%VOW__TB-G"0@
M`0``28UVSC'2B>_H(.7__[HH````2(G>B>_HL>+__[EQ84``38GH3(GGQH0D
M2`$```"^`0```$&Y<&!``#'`:*!A0`!(Q\+_____4^C_Y/__65[I'_[__P\?
MA```````2(MM"$B%[0^$._W__TB)[^@;X___2(/X`P^&*?W__TB-?`7\OFQA
M0`#H0N3__X7`3`]$_>D/_?__Z"+D__]FD%6_DV!``%-(@^P82(L=1H$``&1(
MBP0E*````$B)1"0(,<!(C70D!&1(BRL/MH6P````B(6Q````,<#HX>?__TB%
MP'0)@#@Q#X13`0``,<#H3//__V1(BRM(B>^Y`P```+H!````OI]A0`#H`>+_
M_TB)Q4B%P'0F2(M`$&1(BSNZH6%``$B+,.@4XO__2(M%$$B+,/9&#D`/A3,!
M``!D2(L[N0,```"Z`0```+ZF84``Z+OA__](B<5(A<!T+4B-="0$OV%@0``Q
MP.A2Y___2(G"2(7`#X36````2(M%$&1(BSM(BS#HMN'__V1(BSNZ`0```+ZH
M84``Z,/@__]D2(L[NKUA0`!(B<;HDN'__V1(BP-(C70D!+]88$``QH"Q````
M`#'`Z/;F__](B06/@@``2(G#2(7`=#^^P`$``$B)W^C:X___C5`!@_H!=@F#
M^!$/A8<```!(BT0D"&1(*P0E*`````^%C@```$B#Q!A;7<-F#Q]$``!(BSU)
M@@``Z/SW__](B04U@@``2(G#2(7`=::_:&)``#'`Z-'B__^0@'@!``^$KO[_
M_^F>_O__D$B+!1&"``!(BS!(BT402(LXZ"KJ___I'____P\?1```9$B+.^@W
MXO__Z;_^__^)P4B+!>&!``!(B=J_D&)``$B+,#'`Z'?B___H(N+__V:054B)
M_5-(@^P89$B+!"4H````2(E$)`@QP.A"\/__OB\```!(B<=(B</H0N'__TB%
MP$B-4`%(#T7:2(G?Z+_A__](C70D!+^O8$``2(G#,<#HR^7__TB%P'0F#[80
MA-(/E,"`^C`/E,((T'442(7M=`^`?0``=2EF#Q^$``````!(BT0D"&1(*P0E
M*````'5$2(/$&%M=PV8/'X0``````+H$````OF)A0`!(B=_HCM___X7`=<I(
MBT0D"&1(*P0E*````'4.2(/$&$B)[UM=Z:SF___H1^'__P\?@`````!!5TB)
M_DR-1SA!5D%505154TB![)@"``!D2(L$)2@```!(B80DB`(``#'`3(V,)(``
M``!(B>=F+@\?A```````08L`28L(2(/'$$F#P`@/R(G`2(G*2(E'\$B)R$C!
MZB!(P>@H2,'I."4`_P``2`G(2(G12,'B"$C!X1B!X@``_P")R4@)R$@)T$B)
M1_A,.<]UKF8/;T0D$&8/;UPD($B-1"1H2(V4)&@"``!F#V]4)#!F#V\M)U\`
M``\?@`````#S#V\(9@]OXF8/;U#82(/`$&8/[T"(9@_ORF8/[\%F#V_(9@]S
MT!]F#W/Q`68/Z\%F#]O%#RE`"&8/;\-F#V_<2#G0=;M,BPY,BUX02(M^($B+
M7AA,B<A,B<I(BVX(2(M,)`A(P>H;2,'@!4@)T`,$)$B-C`N9>8):C90XF7F"
M6DR)V$@QV$@AZ$@QV(T\`DB)ZDB)Z$C!Z`)(P>(>28GZ2`G"3(G82<'J&T&)
MT$PQP$PAR$PQV$@!R$B)^4C!X05,"=%,BU0D$$2-)`A,B<A,B<E(P>D"2,'@
M'D^-E!.9>8):38GE2`G(2<'M&T@QPHG!2"'Z3#'"3`'238GB2<'B!4T)ZDR+
M;"0800'22(GZ2,'O`DC!XAY%B=)/C80HF7F"6D@)^DV)U4@QT(G73"'@2<'M
M&T@QR$P!P$V)T$G!X`5-">A,BVPD($$!P$R)X$G![`)(P>`>18G`2HV,*9EY
M@EI,">!-B<5(,<))P>T;08G$3"'22#'Z2`'*3(G!2,'A!4P)Z4R+;"0H`=%,
MB=))P>H"2,'B'HG)2HV\+YEY@EI,"=))B<U(,=!)P>T;08G23"'`3#'@2`'X
M2(G/2,'G!4P)[TR+;"0P`<=,B<!)P>@"2,'@'HG_3XVD+)EY@EI,"<!)B?U(
M,<))P>T;08G`2"'*3#'23`'B28G\2<'D!4T)[$R+;"0X00'42(G*2,'I`DC!
MXAY%B>1/C90JF7F"6D@)RDV)Y4@QT$G![1N)T4@A^$PQP$P!T$V)XDG!X@5-
M">I,BVPD0$$!PDB)^$C![P)(P>`>18G23XV$*)EY@EI("?A-B=5(,<))P>T;
MB<=,(>)(,<I,`<)-B=!)P>`%30GH3(ML)$A!`=!,B>))P>P"2,'B'D6)P$J-
MC"F9>8):3`GB38G%2#'02<'M&T&)U$PAT$@Q^$@!R$R)P4C!X05,">E,BVPD
M4`'!3(G02<'J`DC!X!Z)R4J-O"^9>8):3`G028G-2#'"2<'M&T&)PDPAPDPQ
MXD@!^DB)STC!YP5,">],BVPD6`'73(G"2<'H`DC!XAZ)_T^-I"R9>8):3`G"
M28G]2#'02<'M&T&)T$@AR$PQT$P!X$F)_$G!Y`5-">Q,BVPD8$$!Q$B)R$C!
MX!Y(P>D"18GD3XV4*IEY@EI("<A-B>5(,<))P>T;B<%((?I,,<),`=)-B>))
MP>(%30GJ3(ML)&A!`=)(B?I(P>\"2,'B'D6)TD^-A"B9>8):2`GZ38G52#'0
M2<'M&XG73"'@2#'(3`'`38G02<'@!4T)Z$R+;"1P00'`3(G@2<'L`DC!X!Y%
MB<!*C8PIF7F"6DP)X$V)Q4@QPDG![1M!B<1,(=)(,?I(`<I,B<%(P>$%3`GI
M3(ML)'@!T4R)TDC!XAY)P>H"B<E*C;POF7F"6DP)TDF)S4@QT$G![1M!B=),
M(<!,,>!(`?A(B<](P><%3`GO3(NL)(`````!QTR)P$G!Z`)(P>`>B?]/C:0L
MF7F"6DP)P$F)_4@QPDG![1M!B<!((<I,,=),`>))B?Q)P>0%30GL1HTL(DB)
MRDC!Z0),BZ0DB````$C!XAY("<I/C90BF7F"6DV)[$@QT$G![!N)T4@A^$PQ
MP$P!T$V)ZDG!X@5-">),BZ0DD````$$!PDB)^$C!X!Y(P>\"18G23XV$()EY
M@EI("?A-B=1(,<))P>P;B<=,(>I(,<I,`<)-B=!)P>`%30G@18G`3`'"38GH
M2<'M`DG!X!Y!B=1-">A,BZPDF````$PQP$PAT$J-C"F9>8):38GE2#'X2<'M
M&T@!R$R)X4C!X05,">F)R4@!R$R)T4G!Z@)(P>$>08G%3`G138G"18G`23'*
M1#'23(N4)*````!*C;P7H>O9;DV)ZD@!UTR)ZDG!ZAM(P>(%3`G2B=)(`==,
MB>)(P>(>2<'L`D&)^DP#A"2H````3`GB28G,B<E(`XPDL````$DQU$0QX$V-
MI`"AZ]EN3(G038G02<'H&TC!X`5,"<")P$D!Q$R)Z$G![0)(P>`>18G@3`GH
M28G5B=)(`Y0DN````$DQQ40Q[TR-K#FAZ]EN3(G!3(G'2,'O&TC!X05("?F)
MR4D!S4R)T4G!Z@)(P>$>1(GO3`G128G"B<!),<I%,>).C:02H>O9;DB)^DF)
M^DG!ZAM(P>(%3`G2B=))`=1,B<))P>@"2,'B'D6)XDP)PDF)R$@#A"3`````
MB<E),=!(`XPDR````$4QZ$Z-K`"AZ]EN3(G038G02<'H&TC!X`5,"<")P$D!
MQ4B)^$C![P)(P>`>18GH2`GX2(G7B=)(`Y0DT````$@QQT0QYTR-I#FAZ]EN
M3(G!3(G'2,'O&TC!X05("?F)R4D!S$R)T4G!Z@)(P>$>1(GG3`G128G"B<!(
M`X0DV````$DQRD4QZDZ-K!*AZ]EN2(GZ28GZ2<'J&TC!X@5,"=*)TDD!U4R)
MPDG!Z`)(P>(>18GJ3`G"28G(B<E),=!(`XPDX````$4QX$Z-I`"AZ]EN3(G0
M38G02<'H&TC!X`5,"<")P$D!Q$B)^$C![P)(P>`>18G@2`GX2(G7B=)(`Y0D
MZ````$@QQT0Q[TR-K#FAZ]EN3(G!3(G'2,'O&TC!X05("?F)R4D!S4R)T4G!
MZ@)(P>$>1(GO3`G128G"B<!(`X0D\````$DQRD4QXDZ-I!*AZ]EN2(GZ28GZ
M2<'J&TC!X@5,"=*)TDD!U$R)PDG!Z`)(P>(>18GB3`G"28G(B<E),=!%,>A.
MC:P`H>O9;DR)T$V)T$C!X`5)P>@;2`.,)/@```!,"<")P$D!Q4B)^$C![P)(
MP>`>18GH2`GX2(G7B=)(`Y0D``$``$@QQT0QYTR-I#FAZ]EN3(G!3(G'2,'O
M&TC!X05("?F)R4D!S$R)T4G!Z@)(P>$>1(GG3`G128G"B<!(`X0D"`$``$DQ
MRD4QZDZ-K!*AZ]EN2(GZ28GZ2<'J&TC!X@5,"=*)TDD!U4R)PDG!Z`)(P>(>
M18GJ3`G"28G(B<E),=!%,>!.C:0`H>O9;DR)T$V)T$G!Z!M(P>`%3`G`2`.,
M)!`!``")P$D!Q$B)^$C![P)(P>`>18G@2`GX2(G7B=)(`Y0D&`$``$@QQT0Q
M[TR-K#FAZ]EN3(G!3(G'2,'O&TC!X05("?F)R4D!S4R)T4G!Z@)(P>$>1(GO
M3`G128G"B<!(`X0D(`$``$DQRD4QXDZ-I!*AZ]EN2(GZ28GZ2<'J&TC!X@5,
M"=*)TDD!U$R)PDG!Z`)(P>(>18GB3`G"28G(B<E),=!%,>A.C:P`H>O9;DR)
MT$V)T$G!Z!M(P>`%3`G`B<!)`<5(B?A(P>`>2,'O`D6)Z$@#C"0H`0``2`GX
M2(G7B=)(`Y0D,`$``$@QQT0QYTV)Q$B-C#FAZ]EN3(G'2<'L&TC!YP5,">=-
MB=1)P>H"2<'D'HG_30G428G"2`'YB<!-,>*)ST@#A"0X`0``13'J28G]3HV4
M$J'KV6Y(B?I)P>T;2,'B!4P)ZD$!TDR)PDG!Z`)(P>(>18G23`G"38G@18GD
M23'028G608G51#'!38G02(V,"*'KV6Y,B=!)P>@;2,'@!4P)P$2-!`%(B?E(
MP>\"N-R\&X](P>$>2`GY20G.B<]((?I-(=9)"=9(BY0D0`$``$@!PDP!XDV)
MQ$P!\DV)QDG!Y`5)P>X;30GT00'43(G22<'J`DC!XAY%B>1,"=)("=%)B=9!
MB=))(?Y,(<%,"?%,B[0D2`$``$D!QDT!]4V)YDP!Z4V)Y4G![AM)P>4%30GU
M28G600'-3(G!2<'H`DC!X1Y%B>U,"<%!B<A)"<Y-(>9,(<),"?),B[0D4`$`
M`$D!QDP!]TV)[D@!^DR)[TG![AM(P><%3`GW`==,B>))P>P"2,'B'HG_3`GB
M2`G128G608G432'&3"'I3`GQ3(NT)%@!``!)`<9-`?))B?Y,`=%)B?I)P>X;
M2<'B!4T)\DF)UD$!RDR)Z4G![0)(P>$>18G23`GI08G-20G.22'^3"'J3`GR
M3(NT)&`!``!)`<9-`?!-B=9,`<)-B=!)P>`%2<'N&TT)\$$!T$B)^DC![P)(
MP>(>18G`2`GZ2`G128G6B==-(>Y,(=%,"?%,B[0D:`$``$D!QDT!]$V)QDP!
MX4V)Q$G![AM)P>0%30GT28G600',3(G12<'J`DC!X1Y%B>1,"=%!B<I)"<Y-
M(<9,(=),"?),B[0D<`$``$D!QDT!]4V)YDP!ZDV)Y4G![AM)P>4%30GU00'5
M3(G"2,'B'DG!Z`)%B>U,"<)("=%)B=9!B=!-(=9,(>%,"?%,B[0D>`$``$D!
MQDP!]TV)[D@!^4R)[TG![AM(P><%3`GW28G6`<],B>%)P>P"2,'A'HG_3`GA
M08G,20G.32'N3"'B3`GR3(NT)(`!``!)`<9-`?))B?Y,`=))B?I)P>X;2<'B
M!4T)\D$!TDR)ZDG![0)(P>(>18G23`GJ2`G128G608G52"'Y32'F3`GQ3(NT
M)(@!``!)`<9-`?!-B=9,`<%-B=!)P>X;2<'@!4T)\$F)UD$!R$B)^4C![P)(
MP>$>18G`2`GYB<])"<Y-(=9((?I,"?),B[0DD`$``$D!QDT!]$V)QDP!XDV)
MQ$G![AM)P>0%30GT00'43(G22<'J`DC!XAY%B>1,"=)("=%)B=9!B=))(?Y,
M(<%,"?%,B[0DF`$``$D!QDT!]4V)YDP!Z4V)Y4G![AM)P>4%30GU28G600'-
M3(G!2<'H`DC!X1Y%B>U,"<%!B<A)"<Y-(>9,(<),"?),B[0DH`$``$D!QDP!
M]TV)[D@!^DR)[TG![AM(P><%3`GW`==,B>))P>P"2,'B'HG_3`GB2`G128G6
M08G432'&3"'I3`GQ3(NT)*@!``!)`<9-`?))B?Y,`=%)B?I)P>X;2<'B!4T)
M\DF)UD$!RDR)Z4G![0)(P>$>18G23`GI08G-20G.22'^3"'J3`GR3(NT)+`!
M``!)`<9-`?!-B=9,`<)-B=!)P>X;2<'@!4T)\$$!T$B)^DC![P)(P>(>18G`
M2`GZ2`G128G6B==-(>Y,(=%,"?%,B[0DN`$``$D!QDT!]$V)QDP!X4V)Q$G!
M[AM)P>0%30GT28G600',3(G12<'J`DC!X1Y%B>1,"=%)"<Y!B<I-(<9,(=),
M"?),B[0DP`$``$D!QDT!]4V)YDP!ZDV)Y4G![AM)P>4%30GU00'53(G"2<'H
M`DC!XAY%B>U,"<)("=%)B=!!B==-(=!,(>%,"<%,BX0DR`$``$D!P$P!QTV)
MZ$@!^4R)[TG!Z!M(P><%3`G'1(T$.4R)YTG![`)(B=%(P><>3`GG08G\2`GY
M3"'I3"'B2`G*2(N,)-`!``!(`<%,`=%-B<)(`X0DV`$``$@!RDR)P4G!ZAM(
MP>$%3`G1B<E(`<I,B>E)P>T"2,'A'D&)TDP)Z4@)STF)S4&)SDPAQTTAY4D)
M_4J-/#A,B=!,B[PD^`$``$P![TV)U4C!X`5)P>T;3`GHB<!(`<=,B<!)P>@"
M2,'@'D&)_4D)P+C6P6+*3#'!,=%(BY0DX`$``$@!PDP!XDV)[$@!RDR)Z4G!
M[!M(P>$%3`GA38G4B<E)P>0>2`'*2<'J`DD!QTT)XDV)Q(G118G`33'41#'G
M3(ND).@!``!)`<1-`?1)B<Y,`>=)B<Q)P>X;2<'D!4T)]$V)[DG![0))P>8>
M18GD30GU3(NT)/`!``!,`>=!B?Q)`<9-`?!-B=9-,>Y$,?)-B>9)`=!,B>))
MP>X;2,'B!4P)\HG220'02(G*2,'I`DC!XAY%B<9("<I$B=%-B>I),=),`?E,
MB[PD``(``$0QUTV)\D@!STR)\4C!X05)P>H;20''3`G1B<E(`<],B>%)P>P"
M2,'A'D&)^DD)S$2)Z4F)U8G233'E3`'Y3(N\)!`"``!%,>A-B=5)`<A,B=%)
MP>T;20''2,'A!4P)Z8G)20'(3(GQ2<'N`DC!X1Y%B<5,"?%,B[0D"`(``$D!
MQDP!\DV)YDDQSD0Q]TV)[D@!UTR)ZDG![AM(P>(%3`GRB=)(`==,B=))P>H"
M2,'B'D&)_DD)TD2)XDF)S(G)3`'Z33'43(N\)"`"``!%,>!-B?1)`=!,B?))
MP>P;20''2,'B!4P)XHG220'03(GJ2<'M`DC!XAY%B<1,">I,BZPD&`(``$D!
MQ4P!Z4V)U4DQU40Q[TV)Y4@!STR)X4G![1M(P>$%3`GIB<E(`<],B?%)P>X"
M2,'A'D&)_4D)SD2)T4F)THG233'R3`'Y3(N\)#`"``!%,=!-B>I)`<A,B>E)
MP>H;2,'A!4P)T8G)20'(3(GA2,'A'DG![`)%B<))`<=,">%,BZ0D*`(``$D!
MQ$P!XDV)]$DQS$0QYTV)U$@!UTR)TDG![!M(P>(%3`GBB=)(`==,B>I)P>T"
M2,'B'D&)_$D)U42)\DF)SHG)33'N3`'Z3(N\)$`"``!%,?!-B>9)`=!,B>))
MP>X;2,'B!4P)\HG220'03(G22<'J`DC!XAY%B<9,"=),BY0D.`(``$D!PDP!
MT4V)ZDDQTD0QUTV)\D@!STR)\4C!X05)P>H;20''3`G1B<E(`<],B>%)P>P"
M2,'A'D&)^DD)S$2)Z4F)U8G233'E3`'Y3(N\)&`"``!%,>A-B=5)`<A,B=%)
MP>T;2,'A!4P)Z8G)20'(3(GQ2<'N`DC!X1Y%B<5,"?%,B[0D2`(``$D!QDP!
M\DV)YD6)Y$DQSD0Q]TV)[D@!UTR)ZDG![AM(P>(%3`GRB=)(`==,B=))P>H"
M2,'B'D&)_DD)TDB+E"10`@``2`'"20'42(G*B<E,,=))`<=$,<)-B?!)`=1,
MB?))P>@;2,'B!4P)PHG220'43(GJ2<'M`DC!XAY%B>!,">I,BZPD6`(``$D!
MQ4P!Z4V)U4DQU40Q[TV)Q4@!STR)P4G![1M(P>$%3`GIB<E(`<],B?%)P>X"
M2,'A'D&)_4D)SD2)T4F)THG233'R3`'Y3(N\)'`"``!%,>)-B>Q,`=%-B>I)
MP>P;2<'B!4T)XDV)Q$6)TDG!Y!Y,`=%)P>@"20''30G@3(ND)&@"``!!B<I)
M`<1(`X0D>`(``$P!XDV)]$P!R$TQQ$0QYTV)U$@!UTR)TDG![!M(P>(%3`GB
M38GL2<'M`DG!Y!Z)TDT)Y46)]$V)QD@!UTTQ[HGZ30'\18G`1#'Q28G63`'`
M38GH3`'A28G42<'N&TG!Y`5-"?1$`>%-B=1)P>H"2<'D'HG)30GB33'01#''
M28G(2`'X2(G/2,'G!4G!Z!L!Z4$!VDP)QT0#;B!(B4X(`?A,B5882(D&2(G0
M2,'J`DC!X!Y,B6X@2`G01`'82(E&$$B+A"2(`@``9$@K!"4H````=1)(@<28
M`@``6UU!7$%=05Y!7\/HULK__V8/'T0``$B#[`B_@````.CRR/__9@]O!6I)
M``!(QT`P``````\1`&8/;P5G20``QT!X``````\10!!F#V\%9$D```\10"!(
M@\0(PV9F+@\?A```````05=(8\)!5DF)QD%5051)B?Q52(UO.%-(B?-(@^P(
M2(MW*$B+5S"-#,9(.?%(B4\H2(/2`$C!Z!U(`=!(B4<P2&-'>(7`#X7M````
M08/^/P^.*P$``$&#[D!%B?=!P>\&18UO`4G!Y09)`=T/'T0``/,/;P-,B>=(
M@\-`#Q%%`/,/;TO0#Q%-$/,/;U/@#Q%5(/,/;UOP#Q%=,.BAZ/__3#GK=<Q!
MP><&12G^26/&2(/X"')<28M5`$B-30A(@^'X28E4)#A)BU0%^$B)5`7X2"G-
M2`'H22GM2(/@^$B#^`AR&$B#X/@QTDF+=!4`2(DT$4B#P@A(.<)R[D6)="1X
M2(/$"%M=05Q!74%>05_#9I"H!'5T2(7`=.%!#[95`$&(5"0XJ`)TTT$/MU0%
M_F:)5`7^Z\8/'T``0;]`````2(U\!0!(B=Y!*<=%.?=%#T_^36/O3(GJZ`7*
M__]!BT0D>$0!^$&)1"1X@_A`=9),B>=%*?Y,`>OHQ>?__^G+_O__28G=Z2/_
M__]!BU4`08E4)#A!BU0%_(E4!?SI6____Y!!5DR-=CA!54%454B)_5-,BVXH
M2(GS3(MF,$R)Z$C!Z`.#X#^-2`%(F,9$!CB`2&/!3`'P@_DX#XZ#`0``OD``
M```ISG0/,=*)T8/"`<8$"``Y\G+S2(G?Z$/G__]F#^_`#Q%#.$G'1C``````
M00\11A!!#Q%&($R)XD$/ML5,B>],B>Y(P>H82,'@"$R)X4C![Q!)B=!,B>I(
MP>X8#[;60`^V_T`/MO9(P>D02`G03(GB#[;)2,'@"$@)^`^V_D$/MM!(P>`(
M2`GP00^V]$C!X`A("?!(P>`(2`GX2(G?2,'@"$@)R$C!X`A("=!(B4-PZ*KF
M__](BP-(B=](P>@8B$4`2(L#2,'H$(A%`4B+`XAE`DB+`XA%`TB+0PA(P>@8
MB$4$2(M#"$C!Z!"(105(BT,(B&4&2(M#"(A%!TB+0Q!(P>@8B$4(2(M#$$C!
MZ!"(10E(BT,0B&4*2(M#$(A%"TB+0QA(P>@8B$4,2(M#&$C!Z!"(10U(BT,8
MB&4.2(M#&(A%#TB+0R!(P>@8B$402(M#($C!Z!"(11%(BT,@B&422(M#((A%
M$UM=05Q!74%>Z>K%__]F+@\?A```````NC@````Q_RG*@_H(<D*)T4C'````
M``!(QT0(^`````!(C4@(2(/A^$@IR`'"@^+X@_H(#X)^_O__@^+X,<")QH/`
M"$B)/#$YT'+SZ6?^___VP@1U(X72#X1:_O__Q@``]L("#X1._O__,<EFB4P0
M_NE"_O__#Q\`QP``````QT00_`````#I+/[__P\?1```2(L-L64``.F$Q/__
M2(/L"$B#Q`C#````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````0`"`"5S+R5S`"]P<F]C+W-E;&8O97AE`$1Y;F%,;V%D97(Z.F)O
M;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R\E:2\E
M<P`N`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)
M0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$
M`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"
M54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%
M35``4$%27T=,3T)!3%]#3$5!3@`Q`$Q$7TQ)0E)!4EE?4$%42`!365-414T`
M+W1M<`!414U01$E2`%1-4`!54T52`%5315).04U%`"4P,G@`)7,E<R5S)7,`
M<&%R+0!P87)L`"YP87(`)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M)74E<P`E
M<R5S=&5M<"TE=2TE=25S`!@`<&5R;``P`%!!4CHZ4&%C:V5R.CI615)324].
M`#$N,#4W`"UE`"TM```````````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S
M=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````````)7,Z('!R
M:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V
M92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@```````%5N86)L92!T
M;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y```````````E<SH@8W)E871I;VX@
M;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N
M;STE:2D*``````````!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P
M("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H
M96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!1TE#+"`D1DE,15]O
M9F9S971?<VEZ92P@)&-A8VAE7VYA;65?<VEZ92D["D)%1TE.('L*)%!!4E]-
M04=)0R`](")<;E!!4BYP;5QN(CL*)$9)3$5?;V9F<V5T7W-I>F4@/2`T.R`@
M(",@<&%C:R@B3B(I"B1C86-H95]N86UE7W-I>F4@/2`T,#L*)%!+6DE07TU!
M1TE#(#T@(E!+7#`P,UPP,#0B.PI]"G-U8B!F:6YD7W!A<E]M86=I8PI["FUY
M("@D9F@I(#T@0%\["FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T.PIM>2`D
M8G5F.PIM>2`D<VEZ92`]("US("1F:#L*;7D@)'!O<R`]("@D<VEZ92TQ*2`M
M("@D<VEZ92TQ*2`E("1C:'5N:U]S:7IE.R`@("`@(",@3D]413H@)'!O<R!I
M<R!A(&UU;'1I<&QE(&]F("1C:'5N:U]S:7IE"G=H:6QE("@D<&]S(#X](#`I
M('L*<V5E:R`D9F@L("1P;W,L(#`["G)E860@)&9H+"`D8G5F+"`D8VAU;FM?
M<VEZ92`K(&QE;F=T:"@D4$%27TU!1TE#*3L*:68@*"AM>2`D:2`](')I;F1E
M>"@D8G5F+"`D4$%27TU!1TE#*2D@/CT@,"D@>PIR971U<FX@)'!O<R`K("1I
M.PI]"B1P;W,@+3T@)&-H=6YK7W-I>F4["GT*<F5T=7)N("TQ.PI]"FUY("@D
M<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H92D[
M"D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI4
M96UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P
M96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R
M7W1E;7`I.PIO=71S*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B
M72D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I
M<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF
M("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP
M(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)
M4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8
M(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]("1T
M;7`M/F9I;&5N86UE.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI;&4@
M6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA
M("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E
M>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E("1T
M;7`["F-H;6]D(#`W,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL96YA
M;64@/B]D978O;G5L;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H<7%;
M4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P
M.B`D9FEL96YA;65=*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ
M0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L
M('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"
M54=].PIM>2`E<WES(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7
M:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_
M.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@
M("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*
M7W-E=%]P<F]G;F%M92@I.PIO=71S*'%Q6UPD<')O9VYA;64@/2`B)'!R;V=N
M86UE(ETI.PI?<V5T7W!A<E]T96UP*"D["F]U=',H<7%;7"1%3E9[4$%27U1%
M35!](#T@(B1%3E9[4$%27U1%35!](ETI.PIM>2`H)'-T87)T7W!O<RP@)'-T
M87)T7V]F7T9)3$5?<V5C=&EO;BD["DU!1TE#.B!["FQO8V%L("1324=[7U]7
M05).7U]](#T@<W5B('M].PIU;FQE<W,@*&]P96X@7T9(+"`G/#IR87<G+"`D
M<')O9VYA;64I('L*;W5T<RAQ<5M#86XG="!R96%D(&9R;VT@9FEL92`B)'!R
M;V=N86UE(ETI.R`@(R!D;VXG="!U<V4@)"$@:&5R92!A<R!I="!R97%U:7)E
M<R!%<G)N;RYP;0IL87-T($U!1TE#.PI]"FUY("1M86=I8U]P;W,@/2!F:6YD
M7W!A<E]M86=I8R@J7T9(*3L*:68@*"1M86=I8U]P;W,@/"`P*2!["F]U=',H
M<7%;0V%N)W0@9FEN9"!M86=I8R!S=')I;F<@(B1005)?34%'24,B(&EN(&9I
M;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0SL*?0IO=71S*")&;W5N9"!0
M05(@;6%G:6,@870@<&]S:71I;VX@)&UA9VEC7W!O<R(I.PIS965K(%]&2"P@
M)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE("T@;&5N9W1H*")<,$-!
M0TA%(BDL(#`["G)E860@7T9(+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*
M:68@*"1B=68@;F4@(EPP0T%#2$4B("8F("1B=68@;F4@(EPP0TQ%04XB*2![
M"F]U=',H(DYO(&-A8VAE(&UA<FME<B!F;W5N9"(I.PIL87-T($U!1TE#.PI]
M"F]U=',H<7%;0V%C:&4@;6%R:V5R("(D8G5F(B!F;W5N9%TI.PIS965K(%]&
M2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE+"`P.PIR96%D(%]&
M2"P@)&)U9BP@)$9)3$5?;V9F<V5T7W-I>F4["FUY("1O9F9S970@/2!U;G!A
M8VLH(DXB+"`D8G5F*3L*;W5T<R@B3V9F<V5T(&9R;VT@<W1A<G0@;V8@1DE,
M17,@:7,@)&]F9G-E="(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%
M7V]F9G-E=%]S:7IE("T@)&]F9G-E="P@,#L*)'-T87)T7V]F7T9)3$5?<V5C
M=&EO;B`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@
M)&)U9BP@-#L@("`@("`@("`@("`@("`@("`@("`@("`@("`C(')E860@=&AE
M(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?
M1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F
M*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<5M5;G!A8VMI;F<@1DE,
M12`B)&9U;&QN86UE(BXN+ETI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@
M<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N
M86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D[
M"G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").
M(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_
M.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B
M)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H
M97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A
M8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS:68@*"`D9G5L;&YA
M;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]
M("D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&)A<V5N86UE)&5X="(L
M("1B=68L(#`W-34I.PIO=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*?0IE
M;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F
M+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["B1R97%U:7)E
M7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO
M8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR
M971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I;F9O(#T@
M)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR971U<FX@=6YL97-S("1I;F9O.PID
M96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?3L*)$E.0WLD;6]D=6QE?2`]
M("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y]
M(&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ
M1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A=&4@=&5M<"!F
M:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I;F9O+3Y[
M8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*
M;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP;2(L("1I
M;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@/2`D9FEL96YA;64["F]P96X@
M;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T(')E
M860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S
M=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO9'5L92`D;6]D=6QE(2([
M"GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A
M=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE
M879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@
M24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R
M97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R
M("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<
M+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F
M:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP
M;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0II
M9B`H)&)U9B!N92`D4$M:25!?34%'24,I('L*;W5T<RAQ<5M.;R!Z:7`@9F]U
M;F0@869T97(@1DE,12!S96-T:6]N(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*
M;&%S="!-04=)0R`["GT*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@
M("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*
M;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE
M=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y
M(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*:68@*"$D<W1A<G1?<&]S(&]R("@D
M05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D
M:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R
M"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A
M<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS
M:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6
M.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O
M7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),
M8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S
M:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L
M(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R
M7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]
M"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I
M9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@
M97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO
M<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G
M(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE
M7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I
M<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I
M;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]
M*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R
M($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*
M?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!
M<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]
M('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO
M<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN
M9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G
M*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M
M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH
M*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<&%R
M(ET["GT*;7D@)6UE=&%?<&%R(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE
M=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S
M+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^
M("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R
M*2!["F]P96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG
M="!R96%D('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P
M:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@
M=6YL97-S("1B=68@97$@)%!+6DE07TU!1TE#.PIC;&]S92`D<&@["GT*0W)E
M871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L
M"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]21%=2*"D@?"!)
M3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG="!C
M<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D["G-E96L@
M7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D<W1A<G1?;V9?
M1DE,15]S96-T:6]N*2!["G)E860@7T9(+"`D;&]A9&5R+"`D<W1A<G1?;V9?
M1DE,15]S96-T:6]N.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PHD;&]A
M9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L
M;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD
M;&]A9&5R+"`D,"D["GT*)&9H+3YP<FEN="@D;&]A9&5R*0IO<B!D:64@<7%;
M17)R;W(@=W)I=&EN9R!L;V%D97(@=&\@(B1O=70B.B`D(5T["FEF("@D8G5N
M9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?
M9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*
M;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@
M;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E
M>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]
M($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R96%C:"!`:6YC.PIM>2`E9FEL
M97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O
M8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#
M;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!86%@@;&EB7V5X="!V<R!D;&5X
M="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E
M9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D["FEF("AD969I;F5D*&UY("1F
M8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&ME>7TI*2!["B@D9FEL92P@
M)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS92!["F9O<F5A8V@@;7D@)&1I
M<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<421D:7)<12\H+BHI)'QI*2![
M"B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q*3L*;&%S=#L*?0II9B`H)&ME
M>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD?"D@>PII9B`H;7D@)')E9B`]
M("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@
M)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M
M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"GT*;F5X="!U;FQE
M<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D=W)I='1E;GLD;F%M97TK*SL*
M;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X
M=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C:VEN9R!&24Q%("(E<R(N+BY=
M+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4I*3L*;7D@)&-O
M;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB
M=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PIO<&5N(&UY("1T:"P@
M)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE(CH@
M)"%=.PHD8V]N=&5N="`](#PD=&@^.PIC;&]S92`D=&@["E!!4CHZ1FEL=&5R
M.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D/B\D;F%M
M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_
M.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W
M+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*)&9H+3YP<FEN
M="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DL"G-P<FEN
M=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N
M=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI+`HD
M8V]N=&5N="D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@96UB961D960@1DE,
M12!T;R`B)&]U="(Z("0A73L*;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M92)=
M*3L*?0I]"FEF("@D>FEP*2!["B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F
M:"D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2PIO<B!D:64@<7%;17)R;W(@=W)I
M=&EN9R!Z:7`@<&%R="!O9B`B)&]U=")=.PI]"FEF("@D;65T85]P87)[8VQE
M86Y]*2!["B1F:"T^<')I;G0H(EPP0TQ%04XB*3L*?0IE;'-E('L*:68@*"%D
M969I;F5D("1C86-H95]N86UE*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^
M;F5W*#$I.PIS965K("1F:"P@,"P@,#L*)&-T>"T^861D9FEL92@D9F@I.PIS
M965K("1F:"P@,"P@,CL*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E<W0[
M"GT*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L("1C86-H
M95]N86UE7W-I>F4["B1C86-H95]N86UE("X](")<,"(@>"`H)&-A8VAE7VYA
M;65?<VEZ92`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H)&-A
M8VAE7VYA;64L"B)<,$-!0TA%(BD["GT*;7D@)&]F9G-E="`]("1F:"T^=&5L
M;"`M(&QE;F=T:"@D;&]A9&5R*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&]F
M9G-E="DL"B1005)?34%'24,I.PHD9F@M/F-L;W-E(&]R(&1I92!Q<5M%<G)O
M<B!W<FET:6YG('1R86EL97(@;V8@(B1O=70B.B`D(5T["F-H;6]D(#`W-34L
M("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P
M;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ
M.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E
M<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN97<[
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`C($%R8VAI=F4Z.EII<"!O
M<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?
M1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F86EL960Z("0A73L*07)C
M:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R
M8VAI=F4Z.EII<"T^;F5W.PHH)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F
M:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I
M92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<')O9VYA;64B73L*
M07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`
M4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE
M?2`]("1Z:7`["F]U=',H(D5X=')A8W1I;F<@>FEP+BXN(BD["FEF("AD969I
M;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES
M('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@
M>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA
M;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N
M86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I
M;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK
M*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@
M/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C
M=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R
M+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<5M3:VEP<&EN9R`B)&UE
M;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?
M;F%M92)=*3L*?2!E;'-E('L*;W5T<RAQ<5M%>'1R86-T:6YG("(D;65M8F5R
M7VYA;64B('1O("(D9&5S=%]N86UE(BXN+ETI.PHH)&UE;6)E<BT^97AT<F%C
M=%1O1FEL94YA;65D*"1D97-T7VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?
M3TLH*2D*;W(@9&EE('%Q6T5R<F]R(&5X=')A8W1I;F<@>FEP(&UE;6)E<B!T
M;R`B)&1E<W1?;F%M92)=.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D
M7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[
M)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z
M("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R
M8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL
M95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]
M("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N
M86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N
M86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E
M*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ
M4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T
M:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q
M=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R
M.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V
M87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I
M<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X
M<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E
M<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#
M;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*
M<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`[
M"G)E<75I<F4@1&EG97-T.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!
M4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL
M=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT
M96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!]
M.PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L
M87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U
M<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E
M('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C
M86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R
M7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM0
M05)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX[
M"GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?
M5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%
M35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD
M("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U
M:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@
M)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S
M97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@
M)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N
M86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-
M)SL*?0IM>2`D<W1M<&1I<B`]("(D<&%T:"1S>7-[7V1E;&EM?7!A<BTB+G5N
M<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*
M;7D@)&-A8VAE7V1I<CL*:68@*"1%3E9[4$%27T-,14%.?2D@>PHD8V%C:&5?
M9&ER(#T@(G1E;7`M)"0B.PI]"F5L<V4@>PIO<&5N(&UY("1F:"P@(CPZ<F%W
M(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B
M.B`D(5T["FEF("@H;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"1F
M:"DI(#X](#`I('L*<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S
M971?<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I+"`P.PIM>2`D8G5F.PIR96%D
M("1F:"P@)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&5Q(")<
M,$-!0TA%(BD@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E
M=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%(BD*+2`D8V%C:&5?;F%M95]S:7IE
M+"`P.PIR96%D("1F:"P@)&)U9BP@)&-A8VAE7VYA;65?<VEZ93L*)&)U9B`]
M?B!S+UPP+R]G.PHD8V%C:&5?9&ER(#T@(F-A8VAE+21B=68B.PI]"GT*8VQO
M<V4@)&9H.PI]"FEF("@A)&-A8VAE7V1I<BD@>PHD8V%C:&5?9&ER(#T@(G1E
M;7`M)"0B.PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PI]"B1S=&UP9&ER("X]("(D
M<WES>U]D96QI;7TD8V%C:&5?9&ER(CL*;6MD:7(@)'-T;7!D:7(L(#`W-34[
M"B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FQA<W0["GT*)'!A<E]T96UP
M(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^
M("\H+BLI+SL*?0IS=6(@7W-A=F5?87,@>PIM>2`H)&YA;64L("1C;VYT96YT
M<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA
M;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B
M)&9U;&QN86UE+B0D(CL*;7D@)&9H.PHH;W!E;B`D9F@L("<^.G)A=R<L("1T
M96UP;F%M92D*)B8@*'!R:6YT("1F:"`D8V]N=&5N=',I"B8F("AC;&]S92`D
M9F@I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG("(D=&5M<&YA;64B.B`D(5T[
M"F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N
M86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE
M*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*
M:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]0
M4D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G
M;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R
M;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S
M=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI
M;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H
M)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@
M)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF
M("@M<R`B)'!R;V=N86UE)'-Y<WM?97AE?2(I('L*)'!R;V=N86UE("X]("1S
M>7-[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@
M+UQ1)'-Y<WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E
M>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-
M4'T["B1D:7(@/7X@<R]<421S>7-[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M
M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(I+"!L
M87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X
M97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE
M(BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*
M?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%
M3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?
M9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD<WES>U]D96QI;7TD<')O
M9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@
M0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7
M:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA
M;64@/7X@<R]>*#\]7"Y<+C]<421S>7-[7V1E;&EM?5Q%*2\D<'=D)'-Y<WM?
M9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U
M8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK
M*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)
M6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'
M($-!0TA%(%!23T=.04U%("D@*2!["F1E;&5T92`D14Y6>R)005)?)%\B?3L*
M?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[
M(E!!4E\D7R)](#T@)$5.5GLB4$%27T=,3T)!3%\D7R)](&EF(&5X:7-T<R`D
M14Y6>R)005)?1TQ/0D%,7R1?(GT["GT*:68@*"1%3E9[4$%27U1%35!]*2![
M"F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*?0IS=6(@;W5T<R!["G)E='5R
M;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN
M(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*
M<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@
M)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X
M<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R
M;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF
M="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G
M<RD["F1I92!Q<5MP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P
M<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S
M("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I
M9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`[
M"GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I
M9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D
M.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*````````0T%#
M2$4``'!E<FQX<VDN8P````````!68$```````#IA0```````0F%```````!+
M84``````````````````_____P````#_____``````$C16<`````B:O-[P``
M``#^W+J8`````'94,A``````\.'2PP````````````````$;`SOT````'0``
M`*!^__]0`0``,(+__YP%```PA/__$`$``&"$__\\`0``((7__W@!``#PA?__
MQ`$``("&___H`0``\(?__R0"``#PB/__7`(``,")__^0`@```(S__]P"``!`
MC/__^`(``&",__\,`P``((W__S`#```PC?__1`,``#"/__^4`P``8(___[`#
M``"@D/__Z`,``/"4__\$!```8)7__R`$``"`E?__.`0``("6__^(!````)W_
M_S@%````G___9`4``."?___`!0``4+;__Q`&``"@MO__*`8``$"X__]T!@``
MD+K__[@&````````%``````````!>E(``7@0`1L,!PB0`0<0$````!P````8
M@___(@`````````4``````````%Z4@`!>!`!&PP'")`!```0````'````!R#
M__\!`````````"0````P````2'W__Y`#````#A!&#AA*#PMW"(``/QH[*C,D
M(@````!(````6````*"#___,`````$(.$(\"0@X8C@-"#B"-!$(.*(P%00XP
MA@9!#CB#!T0.0`)L"@XX1`XP00XH0@X@0@X80@X00@X(20L`(````*0````D
MA/__@P````!!#A"#`DH.L`$"<0H.$$$."$$+.````,@```"0A/__9`$```!"
M#A"-`D(.&(P#00X@A@1!#BB#!4<.T`%^"@XH00X@00X80@X00@X(1PL`-```
M``0!``#$A?__\@````!"#A",`DL.&(8#00X@@P1'#K"`!`*P"@X@00X800X0
M0@X(1PL````P````/`$``(R&___(`````$(.$(P"1@X8A@-$#B"#!$\.L"`"
M80H.($$.&$$.$$(."$@+2````'`!```HA___,0(```!"#A"/`D(.&(X#0@X@
MC01"#BB,!4$.,(8&1`XX@P='#E`#%0$*#CA!#C!!#BA"#B!"#AA"#A!"#@A%
M"Q@```"\`0``'(G__T``````00X0@P)G#@@````0````V`$``$")__\?````
M`````"````#L`0``3(G__[,`````00X0@P)'#K!``IT*#A!$#@A!"Q`````0
M`@``Z(G__P4`````````3````"0"``#DB?___P$```!"#A"-`D(.&(P#20X@
MA@1!#BB#!4H.X"$"8@H.*$$.($$.&$(.$$(."$@+`I$.Z"%.#O`A;@[H(4$.
MX"$````8````=`(``)2+__\B`````$$.$(,"7`X(````-````)`"``"HB___
M,0$```!!#A"&`D$.&(,#1PZP(`+A"@X800X000X(1`M:"@X81@X000X(3PL8
M````R`(``+",__]&!````$0.(`,1!`H."$4+&````.0"``#DD/__80````!$
M#B`"3@H."$8+`!0``````P``.)'__QT`````1`X06`X(`$P````8`P``0)'_
M_P`!````0@X0C`)!#AB&`TD.((,$1`XP`D(*#B!(#AA!#A!"#@A+"V0*#B!!
M#AA!#A!"#@A("V$..$D.0&`..$$.,```K````&@#``#PD?__?@8```!"#A"/
M`D(.&(X#0@X@C01"#BB,!4$.,(8&20XX@P='#J`#`\\!#J@#3@ZP`VP.J`-"
M#J`#`FT*#CA$#C!!#BA"#B!"#AA"#A!"#@A""P,P`0ZH`T<.L`-?#J@#00Z@
M`U\.J`-(#K`#3PZX`TT.P`-+#J`#`N$*#CA$#C!!#BA"#B!"#AA"#A!"#@A%
M"P+L#J@#2`ZP`T8.J`-!#J`#```H````&`0``,"7___^`0```$$.$(8"1@X8
M@P-$#C`#9`$*#AA!#A!!#@A'"S0```!$!```E)G__]D`````00X0A@)$#AB#
M`T0.,`*+"@X800X000X(2@MJ"@X81`X000X(10L`(````'P$``",?/__\@$`
M``!!#A"#`D0.0`-3`0H.$$,."$$+3````*`$```8FO__:A8```!"#A"/`DD.
M&(X#0@X@C01"#BB,!4$.,(8&00XX@P='#M`%`T(6"@XX00XP00XH0@X@0@X8
M0@X00@X(00L````4````\`0``#BP__]%`````$0.$`)`#@A(````"`4``'"P
M__^?`0```$(.$(\"10X8C@-%#B"-!$(.*(P%1`XPA@9%#CB#!T<.0`+E"@XX
M00XP00XH0@X@0@X80@X00@X(0PL`0````%0%``#$L?__2P(```!"#A".`D8.
M&(T#0@X@C`1!#BB&!40.,(,&`YL!"@XH00X@0@X80@X00@X(3PL````````0
M````F`4``-"S__\,````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````)`F0```````8"9````````!`````````)$"`````````0``````
M``"A`@````````P``````````"!````````-`````````!Q<0```````&0``
M``````#@O4```````!L`````````"``````````:`````````.B]0```````
M'``````````(`````````/7^_V\`````P`-````````%`````````!@*0```
M````!@`````````8!$````````H`````````^@(````````+`````````!@`
M````````%0````````````````````,`````````Z+]````````"````````
M`$`%````````%``````````'`````````!<`````````J`Y````````'````
M`````!@.0```````"`````````"0``````````D`````````&`````````#^
M__]O`````)@-0```````____;P`````!`````````/#__V\`````$@U`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````#PO4``````````````
M```````````````V($```````$8@0```````5B!```````!F($```````'8@
M0```````AB!```````"6($```````*8@0```````MB!```````#&($``````
M`-8@0```````YB!```````#V($````````8A0```````%B%````````F(4``
M`````#8A0```````1B%```````!6(4```````&8A0```````=B%```````"&
M(4```````)8A0```````IB%```````"V(4```````,8A0```````UB%`````
M``#F(4```````/8A0```````!B)````````6(D```````"8B0```````-B)`
M``````!&(D```````%8B0```````9B)```````!V(D```````(8B0```````
MEB)```````"F(D```````+8B0```````QB)```````#6(D```````.8B0```
M````]B)````````&(T```````!8C0```````)B-````````V(T```````$8C
M0```````5B-```````!F(T```````'8C0```````AB-```````"6(T``````
M`*8C0`````````````````````````````I005(N<&T*``````````#88D``
M`````$=#0SH@*$UA9V5I82`Q,BXR+C$M,"XR,#(R,3$Q.2XQ+FUG83DI(#$R
M+C(N,2`R,#(R,3$Q.`!'0T,Z("A-86=E:6$@,3(N,BXQ+3`N,C`R,C$Q,C8N
M,2YM9V$Y*2`Q,BXR+C$@,C`R,C$Q,C8``"YS:'-T<G1A8@`N:6YT97)P`"YN
M;W1E+F=N=2YP<F]P97)T>0`N;F]T92YG;G4N8G5I;&0M:60`+FYO=&4N04))
M+71A9P`N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N
M9VYU+G9E<G-I;VY?<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YI;FET`"YT97AT
M`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+FEN:71?
M87)R87D`+F9I;FE?87)R87D`+F1Y;F%M:6,`+F=O=``N9V]T+G!L=``N9&%T
M80`N8G-S`"YC;VUM96YT````````````````````````````````````````
M````````````````````````````````````````````````````"P````$`
M```"`````````!@#0```````&`,````````<`````````````````````0``
M`````````````````!,````'`````@`````````X`T```````#@#````````
M0`````````````````````@````````````````````F````!P````(`````
M````>`-```````!X`P```````"0````````````````````$````````````
M````````.0````<````"`````````)P#0```````G`,````````@````````
M````````````!````````````````````$<```#V__]O`@````````#``T``
M`````,`#````````6``````````&``````````@```````````````````!1
M````"P````(`````````&`1````````8!``````````&````````!P````$`
M```(`````````!@`````````60````,````"`````````!@*0```````&`H`
M``````#Z`@```````````````````0```````````````````&$```#___]O
M`@`````````2#4```````!(-````````@``````````&``````````(`````
M`````@````````!N````_O__;P(`````````F`U```````"8#0```````(``
M````````!P````$````(````````````````````?0````0````"````````
M`!@.0```````&`X```````"0``````````8`````````"``````````8````
M`````(<````$````0@````````"H#D```````*@.````````0`4````````&
M````%P````@`````````&`````````"1`````0````8``````````"!`````
M````(````````!<````````````````````$````````````````````C```
M``$````&`````````"`@0```````("````````"0`P``````````````````
M$``````````0`````````)<````!````!@````````"P(T```````+`C````
M````;#@``````````````````!````````````````````"=`````0````8`
M````````'%Q````````<7`````````D````````````````````$````````
M````````````HP````$````"``````````!@0````````&````````"`00``
M````````````````$````````````````````*L````!`````@````````"`
MH4```````("A````````]`````````````````````0`````````````````
M``"Y`````0````(`````````>*)```````!XH@```````-@%````````````
M```````(````````````````````PP````X````#`````````."]0```````
MX*T````````(````````````````````"``````````(`````````,\````/
M`````P````````#HO4```````.BM````````"`````````````````````@`
M````````"`````````#;````!@````,`````````\+U```````#PK0``````
M`.`!````````!P`````````(`````````!``````````Y`````$````#````
M`````-"_0```````T*\````````8````````````````````"``````````(
M`````````.D````!`````P````````#HOT```````.BO````````V`$`````
M``````````````@`````````"`````````#R`````0````,`````````P,%`
M``````#`L0```````"@````````````````````(````````````````````
M^`````@````#``````````#"0```````Z+$```````!8````````````````
M````(````````````````````/T````!````,````````````````````.BQ
M````````;@````````````````````$``````````0`````````!`````P``
M``````````````````````!6L@````````8!```````````````````!````
,````````````````
